==> applet-service-1.0.2-20190121.080517-6-sources.jar: com/bizvane/appletservice/interfaces/RedEnvelopesExpandService.java <==
package com.bizvane.appletservice.interfaces;

import com.bizvane.mktcenterservice.models.vo.ActivityRedPacketVO;
import com.bizvane.utils.responseinfo.ResponseData;

/**
 * 红包膨胀活动
 *
 * @author gs
 * @date 2019 01 17
 */
public interface RedEnvelopesExpandService {
    /**
     * 活动详情
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData selectActivityRedPacketDetail(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 参与判定
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData doIfActivityRedPacket(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 发起
     *
     * @param
     * @param
     * @param
     * @return
     */
    void andActivityRedPacketCreateRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 助力
     *
     * @param
     * @param
     * @param
     * @return
     */
    void andActivityRedPacketZhuliRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 拆红包
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData andActivityRedPacketSendCouponRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 助力记录
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData getRedPacketZhuLiRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 领劵记录
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData getRedPacketCoponAppRecord(ActivityRedPacketVO activityRedPacketVO);


}

==> applet-service-1.0.2-20190123.061835-9-sources.jar: com/bizvane/appletservice/interfaces/RedEnvelopesExpandService.java <==
package com.bizvane.appletservice.interfaces;

import com.bizvane.mktcenterservice.models.bo.MktActivityRedPacketRecordBO;
import com.bizvane.mktcenterservice.models.vo.ActivityRedPacketVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;

import java.util.List;

/**
 * 红包膨胀活动
 *
 * @author gs
 * @date 2019 01 17
 */
public interface RedEnvelopesExpandService {
    /**
     * 活动详情
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData selectActivityRedPacketDetail(ActivityRedPacketVO activityRedPacketVO, String memberCode);

    /**
     * 参与判定
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData doIfActivityRedPacket(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 发起
     *
     * @param
     * @param
     * @param
     * @return
     */
    void andActivityRedPacketCreateRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 助力
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData<Integer> andActivityRedPacketZhuliRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 拆红包
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData andActivityRedPacketSendCouponRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 助力记录
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData getRedPacketZhuLiRecord(ActivityRedPacketVO activityRedPacketVO);

    /**
     * 领劵记录
     *
     * @param
     * @param
     * @param
     * @return
     */
    ResponseData<List<MktActivityRedPacketRecordBO>> getRedPacketCoponAppRecord(ActivityRedPacketVO activityRedPacketVO);


}
